@@ -2,7 +2,9 @@ context("test-texture")
 
 g <- raster::setExtent(raster::raster(matrix(1:12, 3)), raster::extent(0, 4, 0, 3))
 test_that("texturing works", {
-  expect_silent(texture_coordinates(raster::brick(etopo, etopo, etopo), etopo))
+  # can give warnings in PROJ6/GDAL3 world
+  #expect_silent(texture_coordinates(raster::brick(etopo, etopo, etopo), etopo))
+  suppressWarnings(expect_is(texture_coordinates(raster::brick(etopo, etopo, etopo), etopo), "matrix"))
 
   expect_error(quadmesh(g, texture = 1e6), "texture must be a 3-layer raster with RGB values")
   expect_error(quadmesh(g, texture = raster::brick(g, g)), "texture must be a 3-layer raster with RGB values")
